@@ -11,7 +11,7 @@ has max_connections => 5;
 has options => sub { {AutoCommit => 1, PrintError => 0, RaiseError => 1} };
 has [qw(password username)] => '';
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub db {
   my $self = shift;
@@ -79,14 +79,14 @@ Mojo::Pg - Mojolicious ♥ PostgreSQL
 
   # Create a table
   my $pg = Mojo::Pg->new('postgresql://postgres@/test');
-  $pg->db->do('create table names (name varchar(255))');
+  $pg->db->do('create table if not exists names (name varchar(255))');
 
   # Insert a few rows
   my $db = $pg->db;
   $db->query('insert into names values (?)', 'Sara');
   $db->query('insert into names values (?)', 'Daniel');
 
-  # Select all rows
+  # Select all rows blocking
   say for $db->query('select * from names')
     ->hashes->map(sub { $_->{name} })->each;
 
@@ -104,14 +104,16 @@ Mojo::Pg - Mojolicious ♥ PostgreSQL
 
 =head1 DESCRIPTION
 
-L<Mojo::Pg> is a tiny wrapper around L<DBD::Pg> that makes PostgreSQL a lot of
-fun to use with the L<Mojolicious> real-time web framework.
+L<Mojo::Pg> is a tiny wrapper around L<DBD::Pg> that makes
+L<PostgreSQL|http://www.postgresql.org> a lot of fun to use with the
+L<Mojolicious|http://mojolicio.us> real-time web framework.
 
-Database handles and statement handles are cached automatically. While all I/O
-operations are performed blocking, you can wait for long running queries
-asynchronously, allowing the L<Mojo::IOLoop> event loop to perform other tasks
-in the meantime. Since database connections usually have a very low latency,
-this often results in very good performance.
+Database and statement handles are cached automatically, so they can be reused
+transparently to increase performance. While all I/O operations are performed
+blocking, you can wait for long running queries asynchronously, allowing the
+L<Mojo::IOLoop> event loop to perform other tasks in the meantime. Since
+database connections usually have a very low latency, this often results in
+very good performance.
 
 All cached database handles will be reset automatically if a new process has
 been forked, this allows multiple processes to share the same L<Mojo::Pg>
@@ -171,7 +173,9 @@ following new ones.
   my $db = $pg->db;
 
 Get L<Mojo::Pg::Database> object for a cached or newly created database
-handle.
+handle. The database handle will be automatically cached again when that
+object is destroyed, so you can handle connection timeouts gracefully by
+holding on to it only for short amounts of time.
 
 =head2 from_string
 
@@ -202,6 +206,9 @@ Parse configuration from connection string.
 Construct a new L<Mojo::Pg> object and parse connection string with
 L</"from_string"> if necessary.
 
+  # Customize configuration further
+  my $pg = Mojo::Pg->new->dsn('dbi:Pg:service=foo');
+
 =head1 AUTHOR
 
 Sebastian Riedel, C<sri@cpan.org>.
